@@ -60,14 +60,6 @@ class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._name)
         return self._name.value
 
-    @name.setter
-    def name(self, value):
-        """
-        :type: string
-        """
-        self._completeIfNotSet(self._name)
-        self._name.value = value
-
     @property
     def label(self):
         """
@@ -76,14 +68,6 @@ class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._label)
         return self._label.value
 
-    @label.setter
-    def label(self, value):
-        """
-        :type: string
-        """
-        self._completeIfNotSet(self._label)
-        self._label.value = value
-
     @property
     def content_type(self):
         """
