@@ -28,9 +28,7 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
 import github.GithubObject
-import six
 
 
 class InputGitTreeElement(object):
@@ -38,20 +36,31 @@ class InputGitTreeElement(object):
     This class represents InputGitTreeElements
     """
 
-    def __init__(self, path, mode, type, content=github.GithubObject.NotSet, sha=github.GithubObject.NotSet):
+    def __init__(
+        self,
+        path,
+        mode,
+        type,
+        content=github.GithubObject.NotSet,
+        sha=github.GithubObject.NotSet,
+    ):
         """
         :param path: string
         :param mode: string
         :param type: string
         :param content: string
-        :param sha: string
+        :param sha: string or None
         """
 
-        assert isinstance(path, (str, six.text_type)), path
-        assert isinstance(mode, (str, six.text_type)), mode
-        assert isinstance(type, (str, six.text_type)), type
-        assert content is github.GithubObject.NotSet or isinstance(content, (str, six.text_type)), content
-        assert sha is github.GithubObject.NotSet or isinstance(sha, (str, six.text_type)), sha
+        assert isinstance(path, str), path
+        assert isinstance(mode, str), mode
+        assert isinstance(type, str), type
+        assert content is github.GithubObject.NotSet or isinstance(
+            content, str
+        ), content
+        assert (
+            sha is github.GithubObject.NotSet or sha is None or isinstance(sha, str)
+        ), sha
         self.__path = path
         self.__mode = mode
         self.__type = type
