@@ -6,6 +6,7 @@
 # Copyright 2017 Simon <spam@esemi.ru>                                         #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Rigas Papathanasopoulos <rigaspapas@gmail.com>                #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -52,7 +53,31 @@ class Installation(github.GithubObject.NonCompletableGithubObject):
 
     @property
     def id(self):
-        return self._id
+        """
+        :type: integer
+        """
+        return self._id.value
+
+    @property
+    def app_id(self):
+        """
+        :type: integer
+        """
+        return self._app_id.value
+
+    @property
+    def target_id(self):
+        """
+        :type: integer
+        """
+        return self._target_id.value
+
+    @property
+    def target_type(self):
+        """
+        :type: string
+        """
+        return self._target_type.value
 
     def get_repos(self):
         """
@@ -72,7 +97,16 @@ class Installation(github.GithubObject.NonCompletableGithubObject):
 
     def _initAttributes(self):
         self._id = github.GithubObject.NotSet
+        self._app_id = github.GithubObject.NotSet
+        self._target_id = github.GithubObject.NotSet
+        self._target_type = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
+        if "app_id" in attributes:  # pragma no branch
+            self._app_id = self._makeIntAttribute(attributes["app_id"])
+        if "target_id" in attributes:  # pragma no branch
+            self._target_id = self._makeIntAttribute(attributes["target_id"])
+        if "target_type" in attributes:  # pragma no branch
+            self._target_type = self._makeStringAttribute(attributes["target_type"])
